@@ -86,7 +86,7 @@
 #define KNEWSTUFF_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFF_NO_DEPRECATED
-#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
 #endif
 #ifdef KNEWSTUFF_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE KNEWSTUFF_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KNEWSTUFF_DEPRECATED_WARNINGS_SINCE 0x55100
 #  endif
 #endif
 
@@ -139,6 +139,12 @@
 #else
 #  define KNEWSTUFF_DEPRECATED_VERSION_5_79(text)
 #endif
+
+#if KNEWSTUFF_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_80(text) KNEWSTUFF_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KNEWSTUFF_DEPRECATED_VERSION_5_80(text)
+#endif
 #define KNEWSTUFF_DEPRECATED_VERSION_5(minor, text)      KNEWSTUFF_DEPRECATED_VERSION_5_##minor(text)
 #define KNEWSTUFF_DEPRECATED_VERSION(major, minor, text) KNEWSTUFF_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KNEWSTUFF_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFF_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
